package de.fitko.fitconnect.api.config;

import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.util.Map;

@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
public class ApplicationConfig {

    @Builder.Default
    private String httpProxyHost = "";
    @Builder.Default
    private Integer httpProxyPort = 0;
    @Builder.Default

    private Integer requestTimeoutInSeconds = 30;
    private String metadataSchemaPath;
    private String privateSigningKeyPath;

    private SenderConfig senderConfig;
    private SubscriberConfig subscriberConfig;

    private Map<EnvironmentName, Environment> environments;
    private EnvironmentName activeEnvironment;

    private ResourcePaths resourcePaths;

    public Environment getEnvironmentByName(final EnvironmentName environmentName) {
        return environments.get(environmentName);
    }

    public Environment getCurrentEnvironment() {
        return getEnvironmentByName(activeEnvironment);
    }

    public String getOAuthTokenEndpoint() {
        return getCurrentEnvironment().getAuthBaseUrl() + resourcePaths.getAuthTokenPath();
    }

    public String getSubmissionsEndpoint() {
        return getSubmissionBaseUrl() + resourcePaths.getSubmissionsPath();
    }

    public String getSubmissionEndpoint() {
        return getSubmissionBaseUrl() + resourcePaths.getSubmissionPath();
    }

    public String getAttachmentEndpoint() {
        return getSubmissionBaseUrl() + resourcePaths.getSubmissionAttachmentPath();
    }

    public String getEventLogEndpoint() {
        return getSubmissionBaseUrl() + resourcePaths.getEventLogPath();
    }

    public String destinationEndpoint() {
        return getSubmissionBaseUrl() + resourcePaths.getDestinationPath();
    }

    public String destinationKeyEndpoint() {
        return getSubmissionBaseUrl() + resourcePaths.getDestinationKeyPath();
    }

    private String getSubmissionBaseUrl() {
        return getCurrentEnvironment().getSubmissionBaseUrl();
    }
}

